@@ -675,11 +675,13 @@ class MainWindow(QtWidgets.QMainWindow):
         private_path = self.plugin_dir
         if os.path.isdir(private_path):
             for name in os.listdir(private_path):
-                if os.path.isdir(os.path.join(private_path, name)):
+                if (os.path.isdir(os.path.join(private_path, name)) and
+                    not (name.startswith('_') or name.startswith('.'))):
                     self.plugin_names.add(name)
         public_path = pkg_resources.resource_filename('nexpy', 'plugins')
         for name in os.listdir(public_path):
-            if os.path.isdir(os.path.join(public_path, name)):
+            if (os.path.isdir(os.path.join(public_path, name)) and
+                not (name.startswith('_') or name.startswith('.'))):
                 self.plugin_names.add(name)
         plugin_paths = [private_path, public_path]
         for plugin_name in set(sorted(self.plugin_names)):
@@ -1793,11 +1795,14 @@ class MainWindow(QtWidgets.QMainWindow):
             node = self.treeview.get_node()
             if node.nxfilemode and node.nxfilemode == 'r':
                 raise NeXusError("NeXus file is locked")
-            elif isinstance(node, NXgroup) and self.copied_node is not None:
-                if self.copied_node.nxname in node:
-                    self.copied_node.nxname = self.copied_node.nxname + '_copy'
+            elif isinstance(node, NXfield):
+                raise NeXusError("Cannot only paste into a NeXus group")
+            elif isinstance(node, NXgroup):
+                if self.copied_node is None:
+                    raise NeXusError("No data in the copy buffer")
                 if node.nxfilemode != 'r':
-                    node.insert(self.copied_node)
+                    dialog = PasteDialog(node, parent=self)
+                    dialog.show()
                     logging.info("'%s' pasted to '%s'"
                                  % (self.copied_node.nxpath, node.nxpath))
                 else:
@@ -1810,13 +1815,8 @@ class MainWindow(QtWidgets.QMainWindow):
             node = self.treeview.get_node()
             if isinstance(node, NXgroup) and self.copied_link is not None:
                 if node.nxfilemode != 'r':
-                    _name, _target, _filename = self.copied_link
-                    if _name in node:
-                        _name = _name + '_copy'
-                    if _filename == 'None' or node.nxfilename == _filename:
-                        node[_name] = NXlink(_target)
-                    else:
-                        node[_name] = NXlink(_target, _filename)
+                    dialog = PasteDialog(node, link=True, parent=self)
+                    dialog.show()
                     logging.info("'%s' pasted as link to '%s'"
                                  % (self.copied_node.nxpath, node.nxpath))
                 else:
@@ -2336,21 +2336,21 @@ class MainWindow(QtWidgets.QMainWindow):
                 menu.removeAction(action)
 
     def _open_nexpy_online_help(self):
-        filename = "https://nexpy.github.io/nexpy/"
-        webbrowser.open(filename, new=1, autoraise=True)
+        url = "https://nexpy.github.io/nexpy/"
+        webbrowser.open(url, new=1, autoraise=True)
 
     def _open_nexusformat_online_notebook(self):
-        filename = ("https://colab.research.google.com/github/nexpy/nexusformat/blob/" +
+        url = ("https://colab.research.google.com/github/nexpy/nexusformat/blob/" +
                     "master/src/nexusformat/notebooks/nexusformat.ipynb")
-        webbrowser.open(filename, new=1, autoraise=True)
+        webbrowser.open(url, new=1, autoraise=True)
 
     def _open_nexus_online_help(self):
-        filename = "http://download.nexusformat.org/doc/html/classes/base_classes/"
-        webbrowser.open(filename, new=1, autoraise=True)
+        url = "http://download.nexusformat.org/doc/html/classes/base_classes/"
+        webbrowser.open(url, new=1, autoraise=True)
 
     def _open_ipython_online_help(self):
-        filename = "https://ipython.readthedocs.io/en/stable/"
-        webbrowser.open(filename, new=1, autoraise=True)
+        url = "https://ipython.readthedocs.io/en/stable/"
+        webbrowser.open(url, new=1, autoraise=True)
 
     def open_example_file(self):
         default_directory = self.default_directory
