@@ -19,7 +19,6 @@ import numpy as np
 
 from .pyqt import QtCore, QtGui, QtWidgets
 
-import matplotlib as mpl
 from matplotlib import cbook, colors
 from matplotlib.patches import Circle, Ellipse, Polygon, Rectangle
 
@@ -513,7 +512,7 @@ class NXCheckBox(QtWidgets.QCheckBox):
 class NXPushButton(QtWidgets.QPushButton):
     """A button with associated label and slot function."""
 
-    def __init__(self, label, slot, parent=None):
+    def __init__(self, label, slot, checkable=False, width=None, parent=None):
         """Initialize button
         
         Parameters
@@ -530,6 +529,10 @@ class NXPushButton(QtWidgets.QPushButton):
         self.setDefault(False)
         self.setAutoDefault(False)
         self.clicked.connect(slot)
+        if checkable:
+            self.setCheckable(True)
+        if width:
+            self.setFixedWidth(width)
 
     def keyPressEvent(self, event):
         """Function to enable the use of keys to press the button.
@@ -616,14 +619,14 @@ class NXColorBox(QtWidgets.QWidget):
             Parent of the color box.
         """
         super(NXColorBox, self).__init__(parent=parent)
-        self.color_text = color
+        self.color_text = get_color(color)
         color = self.qcolor(self.color_text)
         self.layout = QtWidgets.QHBoxLayout()
         self.layout.setContentsMargins(0, 0, 0, 0)
         if label:
             self.layout.addStretch()
             self.layout.addWidget(NXLabel(label))
-        self.textbox = NXLineEdit(colors.to_hex(color.getRgbF()),
+        self.textbox = NXLineEdit(self.color_text,
                                   parent=parent, slot=self.update_color, 
                                   width=width, align='right')
         self.layout.addWidget(self.textbox)
@@ -653,7 +656,7 @@ class NXColorBox(QtWidgets.QWidget):
     def qcolor(self, text):
         """Create a QColor from a Matplotlib color."""
         qcolor = QtGui.QColor()
-        text = str(text)
+        text = get_color(text)
         if text.startswith('#') and len(text)==7:
             correct = '#0123456789abcdef'
             for char in text:
@@ -979,6 +982,10 @@ class NXpatch(object):
         self.allow_resize = resize
         self.plotview.ax.add_patch(self.shape)
 
+    def __getattr__(self, name):
+        """Return Matplotlib attributes if not defined in the class."""
+        return getattr(self.shape, name)
+
     def connect(self):
         'connect to all the events we need'
         self.plotview.deactivate()
@@ -1036,6 +1043,8 @@ class NXpatch(object):
         self.plotview.activate()
 
     def remove(self):
+        if self in self.plotview.shapes:
+            self.plotview.shapes.remove(self)
         self.shape.remove()
         self.plotview.draw()
 
@@ -1056,6 +1065,14 @@ class NXpatch(object):
         self.shape.set_alpha(alpha)
         self.plotview.draw()
 
+    def set_linestyle(self, linestyle):
+        self.shape.set_linestyle(linestyle)
+        self.plotview.draw()
+
+    def set_linewidth(self, linewidth):
+        self.shape.set_linewidth(linewidth)
+        self.plotview.draw()
+
 
 class NXcircle(NXpatch):
 
@@ -1149,7 +1166,8 @@ class NXcircle(NXpatch):
 
 class NXellipse(NXpatch):
 
-    def __init__(self, x, y, dx, dy, border_tol=0.2, resize=True, plotview=None, **opts):
+    def __init__(self, x, y, dx, dy, border_tol=0.2, resize=True, plotview=None, 
+                 **opts):
         shape = Ellipse((float(x),float(y)), dx, dy, **opts)
         if 'linewidth' not in opts:
             shape.set_linewidth(1.0)
@@ -1221,7 +1239,8 @@ class NXellipse(NXpatch):
 
 class NXrectangle(NXpatch):
 
-    def __init__(self, x, y, dx, dy, border_tol=0.1, resize=True, plotview=None, **opts):
+    def __init__(self, x, y, dx, dy, border_tol=0.1, resize=True, plotview=None, 
+                 **opts):
         shape = Rectangle((float(x),float(y)), float(dx), float(dy), **opts)
         if 'linewidth' not in opts:
             shape.set_linewidth(1.0)
@@ -1248,6 +1267,10 @@ class NXrectangle(NXpatch):
     def xy(self):
         return self.rectangle.xy
 
+    def set_bounds(self, x, y, dx, dy):
+        self.rectangle.set_bounds(x, y, dx, dy)
+        self.plotview.draw()
+
     def set_left(self, left):
         self.rectangle.set_x(left)
         self.plotview.draw()
