@@ -11,19 +11,20 @@
 #-----------------------------------------------------------------------------
 
 pkg_requirements = [
-    'nexusformat>=0.6.1',
+    'nexusformat>=0.7.0',
     'numpy',
     'scipy',
     'h5py',
     'qtpy',
-    'ipykernel>=5.2.0',
+    'ipykernel>=6.2.0',
     'qtconsole',
     'ipython',
     'matplotlib',
     'lmfit>=1.0.2',
     'pylatexenc',
     'ansi2html',
-    'pillow'
+    'pillow',
+    'versioneer'
 ]
 extra_requirements = {
     'spec': ['spec2nexus>=2017.901.4',],
